@@ -73,9 +73,9 @@ class User extends UserDA
     /** archive to access
      *
      * @access private
-     * @var string
+     * @var array
      */
-    var $archive;
+    var $archive = array();
 
 
     /** addresses
@@ -94,6 +94,15 @@ class User extends UserDA
     var $role;
 
 
+    /** permission
+     *
+     * @access public
+     * @var archive
+     */
+    var $permission = [];
+
+
+
    /**
      * restdata
      *
@@ -156,46 +165,71 @@ class User extends UserDA
         $this->restdata = $restdata;
         $this->authparam = $authparam;
         $this->filter= $filter;
+
+        $this->permission['SYSINFO']   = false;   // show sysinfo
+        $this->permission['SYSDATA']   = false;   // show SYSDATA container
+        $this->permission['STATS']     = false;   // show server statistics
+        $this->permission['PASSWD']    = false;   // change password
+        $this->permission['USERINFO']  = false;   // change userdata (name, ...)
+        $this->permission['ADDRESS']   = false;   // change adresses
+        $this->permission['ROLE']      = false;   // change role
+        $this->permission['CONTAINER'] = false;   // change container
+
     }
 
     function getAuthzLevel () {
         $level = 0b0;
 
         // defined in pre_init
+
         // BNO_AUTH       2 User authenticated
         // BNO_USER       4 userpanel (change password)
-        // BNO_SYSINFO    8 Show system information
-        // BNO_SYSDATA   16 SYSDATA container
-        // BNO_ADMIN     32 admingui (change address,role)
-        // BNO_STATS     64 statistics
-        // BNO_SITEADM  128 admingui (change container,siteadmin role)
+        // BNO_USERADMIN  8 user admin (change password, userinfo)
+        // BNO_SYSINFO   16 see sysinfo / SYSDATA container
+        // BNO_ADMIN     32 admin (change address,role)
+        // BNO_SITEADM   64 siteadmin (change container,siteadmin role)
 
         if ($this->role == 'AUTH')      { $level = BNO_AUTH ;}
         if ($this->role == 'USER')      { $level = BNO_AUTH|BNO_USER ;}
         if ($this->role == 'USERADMIN') { $level = BNO_AUTH|BNO_USER ;}
-        if ($this->role == 'REVISOR')   { $level = BNO_AUTH|BNO_SYSINFO|BNO_SYSDATA ;}
-        if ($this->role == 'ADMIN')     { $level = BNO_AUTH|BNO_SYSINFO|BNO_SYSDATA|BNO_STATS|BNO_ADMIN;}
+        if ($this->role == 'REVISOR')   { $level = BNO_AUTH|BNO_SYSINFO ;}
+        if ($this->role == 'ADMIN')     { $level = BNO_AUTH|BNO_USER|BNO_SYSINFO|BNO_ADMIN;}
+        if ($this->role == 'SITEADMIN') { $level = BNO_AUTH|BNO_USER|BNO_SYSINFO|BNO_ADMIN|BNO_SITEADMIN;}
 
         return $level;
     }
 
-    function permission($feature) {
-        if (is_string($feature)) {      // 'constant' from Smarty template
-            $feature = constant($feature);
-        }
-        $ret = $feature & $this->getAuthzLevel();
-
-        return $ret;
-    }
-
 
     function setPassword ($pass) { $this->password = password_hash($pass,PASSWORD_BCRYPT); }
 
     function getName () { return $this->name; }
     function setName ($name) { $this->name = $name; }
 
-    function getArchives () { return $this->archive; }
-    function addArchive ($archive) { array_push($this->archive,$archive); }
+    function getArchives ($sysinfo=true) {
+        $clist = array();
+        if ($sysinfo && $this->permission('SYSDATA')) {
+            array_push($clist,'SYSDATA');
+        }
+        $clist = array_merge($clist,$this->archive);
+
+        return $clist;
+    }
+
+    function hasArchive($archive) {
+        $retval = false;
+        if (in_array($archive,$this->getArchives())) {
+            return true;
+        }
+        return false;
+    }
+
+    function addArchive ($archive) {
+        array_push($this->archive,$archive);
+        $this->archive = array_unique($this->archive);
+        sort($this->archive);
+    }
+
+    function getAuthParam ($param) { return $this->authparam[$param]; }
 
     function getAdresses () { return $this->adresses; }
     function setAdresses ($adresses) { $this->adresses = $adresses; }
@@ -203,9 +237,13 @@ class User extends UserDA
     function setRestData ($restdata) { $this->restdata = $restdata; }
     function getRestData () { return $this->restdata; }
 
-    function getAuthParam ($param) { return $this->authparam[$param]; }
+    function getRole () { return $this->role; }
+    function setRole ($role) { $this->role = $role; }
 
     function getFilter() { return $this->filter; }
 
+    function permission($permission)    { return $this->permission[$permission]; }
+    function setPermission($permission) { $this->permission[$permission] = true; }
+
 }
 ?>
