@@ -115,6 +115,7 @@ class UserDA extends Persistence
         $this->password = $row['password'];
         $this->name = $row['name'];
         $this->role = $row['role'];
+        $this->_load_role_permissions();
 
         $this->_load_container();
 
@@ -127,10 +128,6 @@ class UserDA extends Persistence
             array_push($this->addresses,$row['address']);
         }
 
-        if ($this->role == 'ADMIN' || $this->role == 'REVISOR') {
-            array_unshift($this->archive,'SYSDATA');
-        }
-
         return FALSE;
     }
 
@@ -298,10 +295,9 @@ class UserDA extends Persistence
             $sql = "INSERT INTO container (userid,cid) VALUES (?,?)";
             $sth = $DB->db->prepare($sql);
             foreach ($this->archive as $container) {
-                if ($container == 'SYSDATA') continue;
+                if ($container == 'SYSDATA') { continue; }
                 $sth->bindValue(1,$this->id);
                 $sth->bindValue(2,$container);
-
                 $res = $sth->execute();
  
                 $containers .= $container.','; // deprecated
@@ -436,7 +432,6 @@ class UserDA extends Persistence
         }
         $this->archive = array_unique($this->archive);
 
-
         if (!$this->role)    {
             $App->log('[User::external] ROLE not set by external auth',1);
             throw new Exception('ERR_AUTH');
@@ -447,9 +442,7 @@ class UserDA extends Persistence
             throw new Exception('ERR_AUTH');
         }
 
-        if ($this->role == 'ADMIN' || $this->role == 'REVISOR') {
-            array_unshift($this->archive,'SYSDATA');
-        }
+        $this->_load_role_permissions();
         return FALSE;
     }
 
@@ -506,5 +499,29 @@ class UserDA extends Persistence
     }
 
 
+    function _load_role_permissions()
+    {
+        global $App;
+        $App->log('DEBUG Load role permissions.',4);
+
+        switch($this->role) {
+            case 'SITEADMIN':
+                $this->setPermission('CONTAINER');
+            case 'ADMIN':
+                $this->setPermission('ROLE');
+                $this->setPermission('ADDRESS');
+                $this->setPermission('STATS');
+                $this->setPermission('SYSINFO');
+            case 'REVISOR':
+                $this->setPermission('SYSDATA');
+            case 'USERADMIN':
+                $this->setPermission('USERINFO');
+            case 'USER':
+                $this->setPermission('PASSWD');
+            case 'AUTH':
+                break;    
+        }
+    }
+
 }
 ?>
